<?php

/**
*
*/
class Limelight_Meta_Framework
{

	function __construct()
	{
		$this->metaboxes 	= $this->process_metaboxes( $this->get_metaboxes() );
		$this->fields 		= $this->get_fields();

		$this->register_hooks();
	}

	function process_metaboxes( $metaboxes ) {
		foreach ($metaboxes as $key => $metabox) {
			$metaboxes[ $key ] = $this->set_metabox_default($metabox);
		}
		return $metaboxes;
	}

	function set_metabox_default($metabox) {
		$defaults = array(
			'title'         => '',
			'screen'        => null,
			'context'       => null,
			'priority'      => null,
			'single'        => false,
			'save_callback' => null
		);

		return wp_parse_args($metabox, $defaults);
	}

	function register_hooks() {
		add_action( 'load-post.php', array($this, 'setup_metaboxes') );
		add_action( 'load-post-new.php', array($this, 'setup_metaboxes') );
	}

	function setup_metaboxes() {
		/* Add meta boxes on the 'add_meta_boxes' hook. */
		add_action( 'add_meta_boxes', array($this, 'add_metaboxes') );

		/* Save post meta on the 'save_post' hook. */
		add_action( 'save_post', array($this, 'save_meta'), 10, 2 );
	}

	function add_metaboxes() {
		foreach ($this->metaboxes as $key => $metabox) {

			add_meta_box(
				$key,
				$metabox['title'],
				array($this, 'metabox_callback'),
				$metabox['screen'],
				$metabox['context'],
				$metabox['priority'],
				array(
					'id' => $key
				)
			);
		}
	}

	function metabox_callback($post, $args) {
		$meta = get_post_meta($post->ID, $args['id'], true);

		if( $this->metaboxes[ $args['id'] ]['single'] ){
			$field    = $this->fields[ $args['id'] ];
			$callback = isset( $field['callback'] ) && is_callable( $field['callback'] ) ? $field['callback'] : null;

			if( $callback ){
				call_user_func($callback, $field, $meta);
			}
		}
		else {
			foreach ($this->fields[ $args['id'] ] as $field_key => $field) {
				$current  = isset( $meta[ $field_key ] ) ? $meta[ $field_key ] : '';
				$callback = isset( $field['callback'] ) && is_callable( $field['callback'] ) ? $field['callback'] : null;

				if( $callback ){
					call_user_func($callback, $field, $current);
				}
			}
		}
	}

	function save_meta($post_id, $post) {
		foreach ($this->metaboxes as $key => $metabox) {
			if( !isset($_POST[ $key ]) )
				continue;

			$user_val = $_POST[ $key ];

			if( $metabox['save_callback'] && is_callable( $metabox['save_callback'] ) ){
				call_user_func( $metabox['save_callback'], $post_id, $key, $user_val );
			}
			else {
				if( $user_val )
					update_post_meta( $post_id, $key, $user_val );
				else
					delete_post_meta( $post_id, $key );
			}
		}
	}

	protected function get_metaboxes(){
		die('get_metaboxes() is an abstract function and needs to be overridden by a child class');
	}

	protected function get_fields() {
		die('get_fields() is an abstract function and needs to be overridden by a child class');
	}
}

?>