<?php

function limelight_register_options_panel_hooks() {
	$options_panel = new Limelight_Options();
	$options_panel->register_hooks();
}
add_action( 'init', 'limelight_register_options_panel_hooks' );

function limelight_populate_options() {
	$options_panel = new Limelight_Options();
	global $theme_settings;
	$theme_settings = $options_panel->get_options();
}
add_action( 'wp', 'limelight_populate_options' );

function limelight_options_update(){

	$old_option_id = 'limelight_theme_settings';
	$old_settings  = get_option( $old_option_id );

	if( $old_settings ){

		$options = array(
			'favicon'         => array('general', 'custom_favicon'),
			'color_scheme'    => array('styling', 'color_scheme'),
			'layout'          => array('layouts', 'general'),
			'logo'            => array('general', 'logo'),
			'custom_css'      => array('general', 'custom_css'),
			'disable_slider'  => array('slider', 'disable_slider'),
			'show_excerpts'   => array('home', 'show_excerpts'),
			'twitter_url'     => array('social', 'twitter'),
			'fb_url'          => array('social', 'fb'),
			'google_plus_url' => array('social', 'google_plus'),
			'feedburner'      => array('social', 'feedburner'),
			'footer_text'     => array('footer', 'footer_text'),
			'hide_credits'    => array('footer', 'hide_credits'),
		);

		$new_settings = array();
		foreach ($options as $old_key => $new_keys) {

			if( $old_key == 'hide_credits' && $old_settings[ $old_key ] ){
				$old_settings[ $old_key ] = ( $old_settings[ $old_key ] == 'hide' ) ? true : false;
			}

			if( isset( $old_settings[ $old_key ] ) ){
				$new_settings[ $new_keys[0] ][ $new_keys[1] ] = $old_settings[ $old_key ];
			}

		}

		$options_panel = new Limelight_Options();
		update_option( $options_panel->get_option_id(), $new_settings );
	}
}
add_action( 'after_switch_theme', 'limelight_options_update' );

function limelight_get_layouts(){
	return array(
		''                => __('Inherit', 'limelight'),
		'content-sidebar' => __('Right Sidebar', 'limelight'),
		'sidebar-content' => __('Left Sidebar', 'limelight'),
		'fullwidth'       => __('Fullwidth', 'limelight')
	);
}

/**
 * Returns an array of system fonts
 * Feel free to edit this, update the font fallbacks, etc.
 */
function limelight_supported_os_fonts() {
	// OS Font Defaults
	$os_faces = array(
		'Arial, sans-serif'                                       => 'Arial',
		"'Avant Garde', sans-serif"                               => 'Avant Garde',
		'Cambria, Georgia, serif'                                 => 'Cambria',
		'Copse, sans-serif'                                       => 'Copse',
		"Garamond, 'Hoefler Text', Times New Roman, Times, serif" => 'Garamond',
		'Georgia, serif'                                          => 'Georgia',
		"'Helvetica Neue', Helvetica, sans-serif"                 => 'Helvetica Neue',
		'Tahoma, Geneva, sans-serif'                              => 'Tahoma'
	);

	return $os_faces;
}

/**
 * Returns a select list of Google fonts
 * Feel free to edit this, update the fallbacks, etc.
 */

function limelight_supported_google_fonts() {
	// Google Font Defaults
	$google_faces = array(
		'Arvo, serif'                     => 'Arvo (Google)',
		'Copse, sans-serif'               => 'Copse (Google)',
		'Droid Sans, sans-serif'          => 'Droid Sans (Google)',
		'Droid Serif, serif'              => 'Droid Serif (Google)',
		'Lobster, cursive'                => 'Lobster (Google)',
		'Nobile, sans-serif'              => 'Nobile (Google)',
		'Open Sans, sans-serif'           => 'Open Sans (Google)',
		'Oswald, sans-serif'              => 'Oswald (Google)',
		'Pacifico, cursive'               => 'Pacifico (Google)',
		'Rokkitt, serif'                  => 'Rokkit (Google)',
		'PT Sans, sans-serif'             => 'PT Sans (Google)',
		'Quattrocento, serif'             => 'Quattrocento (Google)',
		'Raleway, cursive'                => 'Raleway (Google)',
		'Ubuntu, sans-serif'              => 'Ubuntu (Google)',
		'Yanone Kaffeesatz, sans-serif'   => 'Yanone Kaffeesatz (Google)',
		'Bree Serif, serif'               => 'Bree Serif (Google)',
		'Poiret One, cursive'             => 'Poiret One (Google)',
		'PT Serif, serif'                 => 'PT Serif (Google)',
		'Titillium Web, sans-serif'       => 'Titillium Web (Google)',
		'Merriweather, serif'             => 'Merriweather (Google)',
		'Roboto, sans-serif'              => 'Roboto (Google)',
		'Roboto Slab, serif'              => 'Roboto Slab (Google)',
		'Open Sans Condensed, sans-serif' => 'Open Sans Condensed (Google)'
	);
	return $google_faces;
}

require_once 'options-framework.php';

/**
*
*/
class Limelight_Options extends Limelight_Options_Framework
{
	function __construct()
	{
		parent::__construct( "limelight_theme_options" );
	}

	protected function get_settings_sections() {
		return array(
			'general' => __('Limelight General', 'limelight'),

			'home'    => __('Limelight Homepage', 'limelight'),

			'slider'  => __('Limelight Slider', 'limelight'),

			'layouts' => __('Limelight Layout', 'limelight'),

			'styling' => __('Limelight Styling', 'limelight'),

			'fonts'   => __('Limelight Fonts', 'limelight'),

			'social'  => __('Limelight Social', 'limelight'),

			'footer'  => __('Limelight Footer', 'limelight')
		);
	}

	protected function get_settings_fields() {

		$fonts = array_merge(limelight_supported_os_fonts(), limelight_supported_google_fonts());
		asort($fonts);
		$fonts = array_merge(array('' => 'Inherit'), $fonts);

		$layouts = limelight_get_layouts();

		return array(
			'general' => array(
				'custom_favicon' => array(
					'label'     => __('Favicon', 'limelight'),
					'type'      => 'media_url'
				),

				'logo' 		=> array(
					'label'     => __('Logo URL', 'limelight'),
					'type'      => 'media_url'
				),

				'custom_css' => array(
					'label' => __('Custom CSS', 'limelight'),
					'type'  => 'textarea'
				)
			),

			'layouts' => array(
				'sidebar_width' => array(
					'label'   => __('Sidebar Width', 'limelight'),
					'type'      => 'select',
					'choices' => array(
						'' 				=> '25%',
						'sidebar-30' 	=> '30%',
						'sidebar-35' 	=> '35%',
						'sidebar-40' 	=> '40%'
					)
				),

				'general' 	=> array(
					'label'      => __('Layout', 'limelight'),
					'type'       => 'select',
					'choices'    => $layouts
				),

				'single' => array(
					'label'      => __('Single Layout', 'limelight'),
					'type'       => 'select',
					'choices'    => $layouts
				),

				'single_post' => array(
					'label'      => __('Single Post Layout', 'limelight'),
					'type'       => 'select',
					'choices'    => $layouts
				),

				'single_page' => array(
					'label'      => __('Single Page Layout', 'limelight'),
					'type'       => 'select',
					'choices'    => $layouts
				),

				'archive' => array(
					'label'      => __('Archive Layout', 'limelight'),
					'type'       => 'select',
					'choices'    => $layouts
				),

				'archive_category' => array(
					'label'      => __('Category Archive Layout', 'limelight'),
					'type'       => 'select',
					'choices'    => $layouts
				),

				'archive_tag' => array(
					'label'      => __('Tag Archive Layout', 'limelight'),
					'type'       => 'select',
					'choices'    => $layouts
				)
			),

			'home' => array(
				'show_excerpts' => array(
					'label'     => __('Show Excerpts', 'limelight'),
					'type'      => 'checkbox'
				),
			),

			'slider' => array(
				'disable_slider' => array(
					'label'     => __('Disable slider?', 'limelight'),
					'type'      => 'checkbox'
				),

				'slides' 	=> array(
					'label'  => __('Slider Images', 'limelight'),
					'type'   => 'media_items'
				),

				'transitionStyle' => array(
					'label'   => __('Transition Style', 'limelight'),
					'type'    => 'select',
					'choices' => array(
						''          => __('Slide', 'limelight'),
						'fade'      => __('Fade', 'limelight'),
						'backSlide' => __('Back Slide', 'limelight'),
						'goDown'    => __('Go Down', 'limelight'),
						'fadeUp'    => __('Fade Up', 'limelight')
					),
				),

				'pagination' => array(
					'label'     => __('Display Pagination', 'limelight'),
					'type'      => 'checkbox',
					'default'   => true
				),

				'autoPlay' => array(
					'label'     => __('Auto Play', 'limelight'),
					'type'      => 'checkbox',
					'default'   => false
				),

				'stopOnHover' => array(
					'label'     => __('Stop On Hover', 'limelight'),
					'type'      => 'checkbox',
					'default'   => false
				),

				'navigation'  => array(
					'label'     => __('Display Navigation', 'limelight'),
					'type'      => 'checkbox',
					'default'   => false
				)
			),

			'styling' => array(
				'color_scheme' 	=> array(
					'label'   => __('Color Scheme', 'limelight'),
					'type'    => 'select',
					'default' => 'green',
					'choices' => array(
						'asbestos'      => __('Asbestos', 'limelight'),
						'blue'          => __('Belize Blue', 'limelight'),
						'dark'          => __('Dark', 'limelight'),
						'midnight-blue' => __('Midnight Blue', 'limelight'),
						'orange'        => __('Orange', 'limelight'),
						'red'           => __('Pomegranate', 'limelight'),
						'pumpkin'       => __('Pumpkin', 'limelight'),
						'green'         => __('Sea Green', 'limelight'),
						'wisteria'      => __('Wisteria', 'limelight')
					)
				),

				'bg_color' => array(
					'type' 	=> 'nested',
					'items' => array(
						'format' 	=> array(
							'type'       => 'hidden',
							'default'    => 'body{background-color:%s;}',
							'customizer' => false
						),
						'value' 	=> array(
							'label' => __('Background Color', 'limelight'),
							'type'  => 'color'
						)
					)
				),

				'bg_img' 	=> array(
					'type' 	=> 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'body{background-image:url(%s);}',
							'customizer' => false
						),
						'value' => array(
							'label' => __('Background Image', 'limelight'),
							'type'  => 'media_url'
						)
					)
				),

				'bg_repeat' 	=> array(
					'type' 	=> 'nested',
					'items' => array(
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'body{background-repeat:%s;}',
							'customizer' => false
						),
						'value' => array(
							'label'   => __('Background Repeat', 'limelight'),
							'type'    => 'select',
							'choices' => array('repeat' => __('Horizontally & vertically', 'limelight'), 'repeat-x' => __('Horizontally', 'limelight'), 'repeat-y' => __('Vertically', 'limelight'))
						)
					)
				)
			),

			'fonts' => array(
				'font_size' => array(
					'type'   => 'nested',
					'items'  => array (
						'format' => array(
							'type'       => 'hidden',
							'default'    => 'body, button, input, select, textarea{font-size:%spx;}',
							'customizer' => false
						),
						'value' => array(
							'label'     => __('Font Size', 'limelight'),
							'type'      => 'number',
							'default'   => 16
						)
					)
				),

				'font_family'	=> array(
					'type' 	=> 'nested',
					'items' 	=> array(
						'format' 	=> array(
							'type'       => 'hidden',
							'default'    => 'body, button, input, select, textarea{font-family:%s;}',
							'customizer' => false
						),
						'value' 	=> array(
							'label'     => __('Basic Font', 'limelight'),
							'type'      => 'select',
							'choices'   => $fonts
						)
					)
				),

				'headings_font_family' 	=> array(
					'type' 	=> 'nested',
					'items' 	=> array(
						'format' 	=> array(
							'type'       => 'hidden',
							'default'    => 'h1,h2,h3,h4,h5,h6{font-family:%s;}',
							'customizer' => false
						),
						'value' 	=> array(
							'label'     => __('Headings Font', 'limelight'),
							'type'      => 'select',
							'choices'   => $fonts
						)
					)
				),

				'site_title_font_family' 	=> array(
					'type' 	=> 'nested',
					'items' 	=> array(
						'format' 	=> array(
							'type'       => 'hidden',
							'default'    => '.site-header .site-branding .site-title{font-family:%s;}',
							'customizer' => false
						),
						'value' 	=> array(
							'label'     => __('Site Title Font', 'limelight'),
							'type'      => 'select',
							'choices'   => $fonts
						)
					)
				),

				'post_title_font_family' 	=> array(
					'type' 	=> 'nested',
					'items' 	=> array(
						'format' 	=> array(
							'type'       => 'hidden',
							'default'    => '.entry-title{font-family:%s;}',
							'customizer' => false
						),
						'value' 	=> array(
							'label'     => __('Post Title Font', 'limelight'),
							'type'      => 'select',
							'choices'   => $fonts
						)
					)
				),

				'widget_title_font_family' 	=> array(
					'type'  => 'nested',
					'items' => array(
						'format' 	=> array(
							'type'       => 'hidden',
							'default'    => '.widget .widget-title{font-family:%s;}',
							'customizer' => false
						),
						'value' 	=> array(
							'label'     => __('Widget Title Font', 'limelight'),
							'type'      => 'select',
							'choices'   => $fonts
						)
					)
				),
			),

			'social' => array(
				'twitter' => array(
					'label'     => __('Twitter URL', 'limelight'),
					'type'      => 'url'
				),

				'fb' 	=> array(
					'label'     => __('Facebook URL', 'limelight'),
					'type'      => 'url'
				),

				'google_plus' => array(
					'label'     => __('Google Plus URL', 'limelight'),
					'type'      => 'url'
				),

				'instagram' => array(
					'label'     => __('Instagram URL', 'limelight'),
					'type'      => 'url'
				),

				'pinterest' => array(
					'label'     => __('Pinterest URL', 'limelight'),
					'type'      => 'url'
				),

				'youtube' => array(
					'label'     => __('Youtube URL', 'limelight'),
					'type'      => 'url'
				),

				'feedburner' => array(
					'label'     => __('Feedburner URL', 'limelight'),
					'type'      => 'url'
				)
			),

			'footer' => array(
				'footer_text' => array(
					'label'      => __('Footer Copyright Text', 'limelight'),
					'type'       => 'text',
					'default'    => '&copy; ' . get_bloginfo('name')
				),

				'hide_credits' => array(
					'label'     => __('Hide credit link?', 'limelight'),
					'type'      => 'checkbox'
				),

				'credits' => array(
					'type'    => 'hidden',
					'default' => $this->get_credits()
				)
			)
		);
	}

	function get_credits(){
		if( is_front_page() || is_home() || is_page() ){
			$format 			= array( '%1$s %5$s <a href="%3$s">%2$s</a>', '%1$s %5$s <a rel="nofollow" href="%3$s">%2$s</a>', '%1$s %5$s <a title="%2$s" href="%3$s">%2$s</a>', '%1$s %5$s <a title="%2$s" rel="nofollow" href="%3$s">%2$s</a>', '<a href="%3$s">%1$s</a> %5$s %2$s', '<a rel="nofollow" href="%3$s">%1$s</a> %5$s %2$s', '<a href="%4$s">%1$s</a> %5$s %2$s', '<a rel="nofollow" href="%4$s">%1$s</a> %5$s %2$s', '<a title="%1$s" href="%4$s">%1$s</a> %5$s %2$s' );
			$anchors 			= array(__('WordPress Theme', 'limelight'), __('Theme', 'limelight'), __('Design', 'limelight'), __('Free WordPress Theme', 'limelight'), __('Free Theme', 'limelight'), __('Designed', 'limelight'), __('Developed', 'limelight'));
			$secondary_anchors 	= array(__('WP Gurus', 'limelight'), __('WP Gurus', 'limelight'), __('WordPress Gurus', 'limelight'));
			$urls 				= array('http://wpgurus.net/', 'http://www.wpgurus.net/', 'http://wpgurus.com/', 'http://www.wpgurus.com/');
			$theme_urls 		= array('http://wpgurus.net/limelight/', 'http://www.wpgurus.net/limelight/', 'http://wpgurus.com/limelight/', 'http://www.wpgurus.com/limelight/');

			$numbers 			= array_map('intval', str_split((string) crc32(get_home_url())));

			return sprintf(
				$this->available_val($format, $numbers[0]),
				$this->available_val($anchors, $numbers[1]),
				$this->available_val($secondary_anchors, $numbers[2]),
				$this->available_val($urls, $numbers[3]),
				$this->available_val($theme_urls, $numbers[4]),
				__('by', 'limelight')
			);
		}
		else {
			return sprintf( __('Powered by %s', 'limelight'), sprintf('<a href="http://wordpress.org/"><i class="fa fa-wordpress"></i></a>') );
		}
	}

	function available_val($array, $index){
		while( !isset($array[$index]) ){
			$index = intval( $index/2 );
		}

		return $array[$index];
	}
}